Module option_names

Module option_names 

Option names, so a typo is a compile error rather than a runtime one.

Every constant here is a name tmux declares. A user option, whose name begins with @, has no constant because tmux does not declare one.

Constants

ACTIVITY_ACTION
tmux’s activity-action option.
AFTER_BIND_KEY
tmux’s after-bind-key option.
AFTER_CAPTURE_PANE
tmux’s after-capture-pane option.
AFTER_COPY_MODE
tmux’s after-copy-mode option.
AFTER_DISPLAY_MESSAGE
tmux’s after-display-message option.
AFTER_DISPLAY_PANES
tmux’s after-display-panes option.
AFTER_KILL_PANE
tmux’s after-kill-pane option.
AFTER_LIST_BUFFERS
tmux’s after-list-buffers option.
AFTER_LIST_CLIENTS
tmux’s after-list-clients option.
AFTER_LIST_KEYS
tmux’s after-list-keys option.
AFTER_LIST_PANES
tmux’s after-list-panes option.
AFTER_LIST_SESSIONS
tmux’s after-list-sessions option.
AFTER_LIST_WINDOWS
tmux’s after-list-windows option.
AFTER_LOAD_BUFFER
tmux’s after-load-buffer option.
AFTER_LOCK_SERVER
tmux’s after-lock-server option.
AFTER_NEW_SESSION
tmux’s after-new-session option.
AFTER_NEW_WINDOW
tmux’s after-new-window option.
AFTER_PASTE_BUFFER
tmux’s after-paste-buffer option.
AFTER_PIPE_PANE
tmux’s after-pipe-pane option.
AFTER_QUEUE
tmux’s after-queue option.
AFTER_REFRESH_CLIENT
tmux’s after-refresh-client option.
AFTER_RENAME_SESSION
tmux’s after-rename-session option.
AFTER_RENAME_WINDOW
tmux’s after-rename-window option.
AFTER_RESIZE_PANE
tmux’s after-resize-pane option.
AFTER_RESIZE_WINDOW
tmux’s after-resize-window option.
AFTER_SAVE_BUFFER
tmux’s after-save-buffer option.
AFTER_SELECT_LAYOUT
tmux’s after-select-layout option.
AFTER_SELECT_PANE
tmux’s after-select-pane option.
AFTER_SELECT_WINDOW
tmux’s after-select-window option.
AFTER_SEND_KEYS
tmux’s after-send-keys option.
AFTER_SET_BUFFER
tmux’s after-set-buffer option.
AFTER_SET_ENVIRONMENT
tmux’s after-set-environment option.
AFTER_SET_HOOK
tmux’s after-set-hook option.
AFTER_SET_OPTION
tmux’s after-set-option option.
AFTER_SHOW_ENVIRONMENT
tmux’s after-show-environment option.
AFTER_SHOW_MESSAGES
tmux’s after-show-messages option.
AFTER_SHOW_OPTIONS
tmux’s after-show-options option.
AFTER_SPLIT_WINDOW
tmux’s after-split-window option.
AFTER_UNBIND_KEY
tmux’s after-unbind-key option.
AGGRESSIVE_RESIZE
tmux’s aggressive-resize option.
ALERT_ACTIVITY
tmux’s alert-activity option.
ALERT_BELL
tmux’s alert-bell option.
ALERT_SILENCE
tmux’s alert-silence option.
ALLOW_PASSTHROUGH
tmux’s allow-passthrough option.
ALLOW_RENAME
tmux’s allow-rename option.
ALLOW_SET_TITLE
tmux’s allow-set-title option.
ALTERNATE_SCREEN
tmux’s alternate-screen option.
ASSUME_PASTE_TIME
tmux’s assume-paste-time option.
AUTOMATIC_RENAME
tmux’s automatic-rename option.
AUTOMATIC_RENAME_FORMAT
tmux’s automatic-rename-format option.
BACKSPACE
tmux’s backspace option.
BASE_INDEX
tmux’s base-index option.
BELL_ACTION
tmux’s bell-action option.
BUFFER_LIMIT
tmux’s buffer-limit option.
CLIENT_ACTIVE
tmux’s client-active option.
CLIENT_ATTACHED
tmux’s client-attached option.
CLIENT_DARK_THEME
tmux’s client-dark-theme option.
CLIENT_DETACHED
tmux’s client-detached option.
CLIENT_FOCUS_IN
tmux’s client-focus-in option.
CLIENT_FOCUS_OUT
tmux’s client-focus-out option.
CLIENT_LIGHT_THEME
tmux’s client-light-theme option.
CLIENT_RESIZED
tmux’s client-resized option.
CLIENT_SESSION_CHANGED
tmux’s client-session-changed option.
CLOCK_MODE_COLOUR
tmux’s clock-mode-colour option.
CLOCK_MODE_STYLE
tmux’s clock-mode-style option.
CODEPOINT_WIDTHS
tmux’s codepoint-widths option.
COMMAND_ALIAS
tmux’s command-alias option.
COMMAND_ERROR
tmux’s command-error option.
COPY_COMMAND
tmux’s copy-command option.
COPY_MODE_CURRENT_LINE_NUMBER_STYLE
tmux’s copy-mode-current-line-number-style option.
COPY_MODE_CURRENT_MATCH_STYLE
tmux’s copy-mode-current-match-style option.
COPY_MODE_LINE_NUMBERS
tmux’s copy-mode-line-numbers option.
COPY_MODE_LINE_NUMBER_STYLE
tmux’s copy-mode-line-number-style option.
COPY_MODE_MARK_STYLE
tmux’s copy-mode-mark-style option.
COPY_MODE_MATCH_STYLE
tmux’s copy-mode-match-style option.
COPY_MODE_POSITION_FORMAT
tmux’s copy-mode-position-format option.
COPY_MODE_POSITION_STYLE
tmux’s copy-mode-position-style option.
COPY_MODE_SELECTION_STYLE
tmux’s copy-mode-selection-style option.
CURSOR_COLOUR
tmux’s cursor-colour option.
CURSOR_STYLE
tmux’s cursor-style option.
DEFAULT_CLIENT_COMMAND
tmux’s default-client-command option.
DEFAULT_COMMAND
tmux’s default-command option.
DEFAULT_SHELL
tmux’s default-shell option.
DEFAULT_SIZE
tmux’s default-size option.
DEFAULT_TERMINAL
tmux’s default-terminal option.
DESTROY_UNATTACHED
tmux’s destroy-unattached option.
DETACH_ON_DESTROY
tmux’s detach-on-destroy option.
DISPLAY_PANES_ACTIVE_COLOUR
tmux’s display-panes-active-colour option.
DISPLAY_PANES_COLOUR
tmux’s display-panes-colour option.
DISPLAY_PANES_TIME
tmux’s display-panes-time option.
DISPLAY_TIME
tmux’s display-time option.
EDITOR
tmux’s editor option.
ESCAPE_TIME
tmux’s escape-time option.
EXIT_EMPTY
tmux’s exit-empty option.
EXIT_UNATTACHED
tmux’s exit-unattached option.
EXTENDED_KEYS
tmux’s extended-keys option.
EXTENDED_KEYS_FORMAT
tmux’s extended-keys-format option.
FILL_CHARACTER
tmux’s fill-character option.
FOCUS_EVENTS
tmux’s focus-events option.
FOCUS_FOLLOWS_MOUSE
tmux’s focus-follows-mouse option.
GET_CLIPBOARD
tmux’s get-clipboard option.
HISTORY_FILE
tmux’s history-file option.
HISTORY_LIMIT
tmux’s history-limit option.
INITIAL_REPEAT_TIME
tmux’s initial-repeat-time option.
INPUT_BUFFER_SIZE
tmux’s input-buffer-size option.
KEY_TABLE
tmux’s key-table option.
LOCK_AFTER_TIME
tmux’s lock-after-time option.
LOCK_COMMAND
tmux’s lock-command option.
MAIN_PANE_HEIGHT
tmux’s main-pane-height option.
MAIN_PANE_WIDTH
tmux’s main-pane-width option.
MENU_BORDER_LINES
tmux’s menu-border-lines option.
MENU_BORDER_STYLE
tmux’s menu-border-style option.
MENU_SELECTED_STYLE
tmux’s menu-selected-style option.
MENU_STYLE
tmux’s menu-style option.
MESSAGE_COMMAND_STYLE
tmux’s message-command-style option.
MESSAGE_FORMAT
tmux’s message-format option.
MESSAGE_LIMIT
tmux’s message-limit option.
MESSAGE_LINE
tmux’s message-line option.
MESSAGE_STYLE
tmux’s message-style option.
MODE_KEYS
tmux’s mode-keys option.
MODE_STYLE
tmux’s mode-style option.
MONITOR_ACTIVITY
tmux’s monitor-activity option.
MONITOR_BELL
tmux’s monitor-bell option.
MONITOR_SILENCE
tmux’s monitor-silence option.
MOUSE
tmux’s mouse option.
OTHER_PANE_HEIGHT
tmux’s other-pane-height option.
OTHER_PANE_WIDTH
tmux’s other-pane-width option.
PANE_ACTIVE_BORDER_STYLE
tmux’s pane-active-border-style option.
PANE_BASE_INDEX
tmux’s pane-base-index option.
PANE_BORDER_FORMAT
tmux’s pane-border-format option.
PANE_BORDER_INDICATORS
tmux’s pane-border-indicators option.
PANE_BORDER_LINES
tmux’s pane-border-lines option.
PANE_BORDER_STATUS
tmux’s pane-border-status option.
PANE_BORDER_STYLE
tmux’s pane-border-style option.
PANE_COLOURS
tmux’s pane-colours option.
PANE_DIED
tmux’s pane-died option.
PANE_EXITED
tmux’s pane-exited option.
PANE_FOCUS_IN
tmux’s pane-focus-in option.
PANE_FOCUS_OUT
tmux’s pane-focus-out option.
PANE_MODE_CHANGED
tmux’s pane-mode-changed option.
PANE_SCROLLBARS
tmux’s pane-scrollbars option.
PANE_SCROLLBARS_POSITION
tmux’s pane-scrollbars-position option.
PANE_SCROLLBARS_STYLE
tmux’s pane-scrollbars-style option.
PANE_SET_CLIPBOARD
tmux’s pane-set-clipboard option.
PANE_STATUS_CURRENT_STYLE
tmux’s pane-status-current-style option.
PANE_STATUS_STYLE
tmux’s pane-status-style option.
PANE_TITLE_CHANGED
tmux’s pane-title-changed option.
POPUP_BORDER_LINES
tmux’s popup-border-lines option.
POPUP_BORDER_STYLE
tmux’s popup-border-style option.
POPUP_STYLE
tmux’s popup-style option.
PREFIX
tmux’s prefix option.
PREFIX2
tmux’s prefix2 option.
PREFIX_TIMEOUT
tmux’s prefix-timeout option.
PROMPT_COMMAND_CURSOR_STYLE
tmux’s prompt-command-cursor-style option.
PROMPT_CURSOR_COLOUR
tmux’s prompt-cursor-colour option.
PROMPT_CURSOR_STYLE
tmux’s prompt-cursor-style option.
PROMPT_HISTORY_LIMIT
tmux’s prompt-history-limit option.
REMAIN_ON_EXIT
tmux’s remain-on-exit option.
REMAIN_ON_EXIT_FORMAT
tmux’s remain-on-exit-format option.
RENUMBER_WINDOWS
tmux’s renumber-windows option.
REPEAT_TIME
tmux’s repeat-time option.
SCROLL_ON_CLEAR
tmux’s scroll-on-clear option.
SESSION_CLOSED
tmux’s session-closed option.
SESSION_CREATED
tmux’s session-created option.
SESSION_RENAMED
tmux’s session-renamed option.
SESSION_STATUS_CURRENT_STYLE
tmux’s session-status-current-style option.
SESSION_STATUS_STYLE
tmux’s session-status-style option.
SESSION_WINDOW_CHANGED
tmux’s session-window-changed option.
SET_CLIPBOARD
tmux’s set-clipboard option.
SET_TITLES
tmux’s set-titles option.
SET_TITLES_STRING
tmux’s set-titles-string option.
SILENCE_ACTION
tmux’s silence-action option.
STATUS
tmux’s status option.
STATUS_BG
tmux’s status-bg option.
STATUS_FG
tmux’s status-fg option.
STATUS_FORMAT
tmux’s status-format option.
STATUS_INTERVAL
tmux’s status-interval option.
STATUS_JUSTIFY
tmux’s status-justify option.
STATUS_KEYS
tmux’s status-keys option.
STATUS_LEFT
tmux’s status-left option.
STATUS_LEFT_LENGTH
tmux’s status-left-length option.
STATUS_LEFT_STYLE
tmux’s status-left-style option.
STATUS_POSITION
tmux’s status-position option.
STATUS_RIGHT
tmux’s status-right option.
STATUS_RIGHT_LENGTH
tmux’s status-right-length option.
STATUS_RIGHT_STYLE
tmux’s status-right-style option.
STATUS_STYLE
tmux’s status-style option.
SYNCHRONIZE_PANES
tmux’s synchronize-panes option.
TERMINAL_FEATURES
tmux’s terminal-features option.
TERMINAL_OVERRIDES
tmux’s terminal-overrides option.
TILED_LAYOUT_MAX_COLUMNS
tmux’s tiled-layout-max-columns option.
TREE_MODE_PREVIEW_FORMAT
tmux’s tree-mode-preview-format option.
TREE_MODE_PREVIEW_STYLE
tmux’s tree-mode-preview-style option.
UPDATE_ENVIRONMENT
tmux’s update-environment option.
USER_KEYS
tmux’s user-keys option.
VARIATION_SELECTOR_ALWAYS_WIDE
tmux’s variation-selector-always-wide option.
VISUAL_ACTIVITY
tmux’s visual-activity option.
VISUAL_BELL
tmux’s visual-bell option.
VISUAL_SILENCE
tmux’s visual-silence option.
WINDOW_ACTIVE_STYLE
tmux’s window-active-style option.
WINDOW_LINKED
tmux’s window-linked option.
WINDOW_PANE_CURRENT_STATUS_FORMAT
tmux’s window-pane-current-status-format option.
WINDOW_PANE_STATUS_FORMAT
tmux’s window-pane-status-format option.
WINDOW_SIZE
tmux’s window-size option.
WINDOW_STATUS_ACTIVITY_STYLE
tmux’s window-status-activity-style option.
WINDOW_STATUS_BELL_STYLE
tmux’s window-status-bell-style option.
WINDOW_STATUS_CURRENT_FORMAT
tmux’s window-status-current-format option.
WINDOW_STATUS_CURRENT_STYLE
tmux’s window-status-current-style option.
WINDOW_STATUS_FORMAT
tmux’s window-status-format option.
WINDOW_STATUS_LAST_STYLE
tmux’s window-status-last-style option.
WINDOW_STATUS_SEPARATOR
tmux’s window-status-separator option.
WINDOW_STATUS_STYLE
tmux’s window-status-style option.
WINDOW_STYLE
tmux’s window-style option.
WINDOW_UNLINKED
tmux’s window-unlinked option.
WORD_SEPARATORS
tmux’s word-separators option.
WRAP_SEARCH
tmux’s wrap-search option.
XTERM_KEYS
tmux’s xterm-keys option.